pbf

package
v0.0.0-...-d580851 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 29, 2018 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ByteParser

func ByteParser(data []byte) osm.Parser

returns an osm.Parser which can be used as argument to osm.New(), reads from byte array

func FileParser

func FileParser(file string) (osm.Parser, io.Closer, error)

returns an osm.Parser which can be used as argument to osm.New(), reads from the given file

func Parser

func Parser(r io.Reader) osm.Parser

returns an osm.Parser which can be used as argument to osm.New()

Types

type Pbf

type Pbf struct {
	// contains filtered or unexported fields
}

func (*Pbf) Parse

func (p *Pbf) Parse(handler osm.OSMReader) (o *osm.OSM, err error)

implements the osm.Parser interface

Jump to