Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ByteParser ¶
returns an osm.Parser which can be used as argument to osm.New(), reads from byte array
func FileParser ¶
returns an osm.Parser which can be used as argument to osm.New(), reads from the given file
Types ¶
Click to show internal directories.
Click to hide internal directories.